from setuptools import setup

setup(
    name='RotaryTableDobotDidactech',
    packages=['RotaryTableDobotDidactech'],
    version='0.1',
    description='Rotary table for Dobot, DIDACTECH development',
    py_modules=['RotaryTableDobot'],
    author='Walter Becerra',
    author_email='becerrawalter20@hotmail.com',
    url=' ',
)